<?php
/*
Class Name: VI_WOOCOMMERCE_THANK_YOU_PAGE_Admin_Admin
Author: Andy Ha (support@villatheme.com)
Author URI: http://villatheme.com
Copyright 2018 villatheme.com. All rights reserved.
*/
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class VI_WOOCOMMERCE_THANK_YOU_PAGE_Admin_Admin {
	protected $settings;
	protected $active_components;

	public function __construct() {
		$this->settings          = new VI_WOOCOMMERCE_THANK_YOU_PAGE_DATA();
		$this->active_components = array();
		add_action( 'admin_notices', array( $this, 'admin_notices' ) );
		add_action( 'init', array( $this, 'init' ) );
	}

	public function load_plugin_textdomain() {
		$locale = apply_filters( 'plugin_locale', get_locale(), 'woocommerce-thank-you-page-customizer' );
		load_textdomain( 'woocommerce-thank-you-page-customizer', VI_WOOCOMMERCE_THANK_YOU_PAGE_LANGUAGES . "woocommerce-thank-you-page-customizer-$locale.mo" );
		load_plugin_textdomain( 'woocommerce-thank-you-page-customizer', false, VI_WOOCOMMERCE_THANK_YOU_PAGE_LANGUAGES );
	}

	public function init() {
		$this->load_plugin_textdomain();
		if ( class_exists( 'VillaTheme_Support_Pro' ) ) {
			new VillaTheme_Support_Pro(
				array(
					'support'   => 'https://villatheme.com/supports/forum/plugins/woocommerce-thank-you-page-customizer/',
					'docs'      => 'http://docs.villatheme.com/?item=woocommerce-thank-you-page-customizer',
					'review'    => 'https://codecanyon.net/downloads',
					'css'       => VI_WOOCOMMERCE_THANK_YOU_PAGE_CSS,
					'image'     => VI_WOOCOMMERCE_THANK_YOU_PAGE_IMAGES,
					'slug'      => 'woocommerce-thank-you-page-customizer',
					'menu_slug' => 'woocommerce_thank_you_page_customizer',
					'version'   => VI_WOOCOMMERCE_THANK_YOU_PAGE_VERSION
				)
			);
		}

		if ( version_compare( VI_WOOCOMMERCE_THANK_YOU_PAGE_VERSION, '1.1.0', '>=' ) ) {
			$this->wtpy_update_db_check();
		}
	}

	public function admin_notices() {
		if ( ! get_option( 'woocommerce_checkout_page_id' ) ) {
			?>
            <div id="message" class="error">
                <p><?php _e( 'Checkout page is not set yet, WooCommerce Thank You Page Customizer is not working. Please set it <a target="_blank" href="' . admin_url( 'admin.php' ) . '?page=wc-settings&tab=advanced">here</a>.', 'woocommerce-thank-you-page-customizer' ); ?></p>
            </div>
			<?php
		}
		if ( isset( $_REQUEST['woocommerce_thank_you_page_customizer_items_removed_notice_hide'] ) && $_REQUEST['woocommerce_thank_you_page_customizer_items_removed_notice_hide'] ) {
			set_transient( 'woocommerce_thank_you_page_customizer_items_removed_notice', 'hide' );
		}
		if ( ! get_transient( 'woocommerce_thank_you_page_customizer_items_removed_notice' ) ) {
			$blocks = json_decode( $this->settings->get_params( 'blocks' ), true );
			array_walk_recursive( $blocks, array( $this, 'get_active_components' ) );
			$removed_components = array(
				'sale_products',
				'best_selling_products',
				'recent_products',
				'recently_viewed_products',
				'featured_products',
				'up_sells_products',
				'cross_sells_products',
				'related_products',
				'top_rated_products',
			);
			if ( count( array_intersect( $this->active_components, $removed_components ) ) ) {
				$url = admin_url( 'customize.php' ) . '?autofocus[section]=woo_thank_you_page_design_general';
				if ( $this->settings->get_params( 'select_order' ) ) {
					$order = wc_get_order( $this->settings->get_params( 'select_order' ) );
					if ( $order ) {
						$url = admin_url( 'customize.php' ) . '?url=' . urlencode( $order->get_checkout_order_received_url() ) . '&autofocus[section]=woo_thank_you_page_design_general';
					}
				}
				?>
                <div id="message" class="error">
                    <p><?php _e( 'Thank you for using WooCommerce Thank You Page Customizer. We replaced some products items with the new item that have more options in the latest update; therefore those old products items will not work any more. Please go to <a target="_blank" href="' . $url . '">cutomize</a> to update your Thank you page. We are sorry for this inconvenience.', 'woocommerce-thank-you-page-customizer' ); ?></p>
                    <p>
                        <a href="<?php echo add_query_arg( array( 'woocommerce_thank_you_page_customizer_items_removed_notice_hide' => 1 ) ) ?>"
                           class="button"><?php esc_html_e( 'Got it', 'woocommerce-thank-you-page-customizer' ); ?></a></p>
                </div>
				<?php
			}
		}

	}

	public function get_active_components( $value, $key ) {
		if ( ! in_array( $value, $this->active_components ) ) {
			$this->active_components[] = $value;
		}
	}

	/**
	 * Function merge data old to new version
	 *
	 * @return void
	 * @since 1.1.0
	 */
	public function wtpy_update_db_check() {

		$list_contents_helper        = array(
			'text_editor',
			'products',
			'blocks'
		);
		$list_blocks_helper          = array(
			'thank_you_message',
			'order_confirmation',
			'order_details',
			'customer_information',
			'coupon',
			'social_icons',
			'google_map',
			'bing_map',
		);
		$list_child_components       = array(
			'thank_you_message'    => array(
				'thank_you_message_padding',
				'thank_you_message_color',
				'thank_you_message_text_align',
				'thank_you_message_header',
				'thank_you_message_header_font_size',
				'thank_you_message_message',
				'thank_you_message_message_font_size',
			),
			'order_confirmation'   => array(
				'order_confirmation_bg',
				'order_confirmation_padding',
				'order_confirmation_border_radius',
				'order_confirmation_border_width',
				'order_confirmation_border_style',
				'order_confirmation_border_color',
				'order_confirmation_vertical_width',
				'order_confirmation_vertical_style',
				'order_confirmation_vertical_color',
				'order_confirmation_horizontal_width',
				'order_confirmation_horizontal_style',
				'order_confirmation_horizontal_color',
				'order_confirmation_header',
				'order_confirmation_header_color',
				'order_confirmation_header_bg_color',
				'order_confirmation_header_font_size',
				'order_confirmation_header_text_align',
				'order_confirmation_title_color',
				'order_confirmation_title_bg_color',
				'order_confirmation_title_font_size',
				'order_confirmation_title_text_align',
				'order_confirmation_value_color',
				'order_confirmation_value_bg_color',
				'order_confirmation_value_font_size',
				'order_confirmation_value_text_align',
				'order_confirmation_order_number_title',
				'order_confirmation_date_title',
				'order_confirmation_order_total_title',
				'order_confirmation_email_title',
				'order_confirmation_payment_title',
			),
			'order_details'        => array(
				'order_details_color',
				'order_details_bg',
				'order_details_padding',
				'order_details_border_radius',
				'order_details_border_width',
				'order_details_border_style',
				'order_details_border_color',
				'order_details_font_size',
				'order_details_horizontal_width',
				'order_details_horizontal_style',
				'order_details_horizontal_color',
				'order_details_header',
				'order_details_header_color',
				'order_details_header_bg_color',
				'order_details_header_font_size',
				'order_details_header_text_align',
				'order_details_product_title_text',
				'order_details_product_value_text',
				'order_details_product_image',
				'order_details_product_image_width',
				'order_details_product_quantity_in_image',
			),
			'customer_information' => array(
				'customer_information_color',
				'customer_information_bg',
				'customer_information_padding',
				'customer_information_border_radius',
				'customer_information_border_width',
				'customer_information_border_style',
				'customer_information_border_color',
				'customer_information_vertical_width',
				'customer_information_vertical_style',
				'customer_information_vertical_color',
				'customer_information_header',
				'customer_information_header_color',
				'customer_information_header_font_size',
				'customer_information_header_text_align',
				'customer_information_billing_title',
				'customer_information_shipping_title',
				'customer_information_address_color',
				'customer_information_address_bg_color',
				'customer_information_address_font_size',
				'customer_information_address_text_align',
			),
			'coupon'               => array(
				'coupon_text_align',
				'coupon_text_padding',
				'coupon_message',
				'coupon_message_color',
				'coupon_message_font_size',
				'coupon_code_color',
				'coupon_code_bg_color',
				'coupon_code_border_width',
				'coupon_code_border_style',
				'coupon_code_border_color',
				'coupon_scissors_color',
				'coupon_woo_email_enable',
			),
			'social_icons'         => array(
				'social_icons_header',
				'social_icons_header_color',
				'social_icons_header_font_size',
				'social_icons_align',
				'social_icons_space',
				'social_icons_size',
				'social_icons_target',
				'social_icons_tiktok_url',
				'social_icons_tiktok_select',
				'social_icons_tiktok_color',
				'social_icons_facebook_url',
				'social_icons_facebook_select',
				'social_icons_facebook_color',
				'social_icons_twitter_url',
				'social_icons_twitter_select',
				'social_icons_twitter_color',
				'social_icons_pinterest_url',
				'social_icons_pinterest_select',
				'social_icons_pinterest_color',
				'social_icons_instagram_url',
				'social_icons_instagram_select',
				'social_icons_instagram_color',
				'social_icons_dribbble_url',
				'social_icons_dribbble_select',
				'social_icons_dribbble_color',
				'social_icons_tumblr_url',
				'social_icons_tumblr_select',
				'social_icons_tumblr_color',
				'social_icons_google_url',
				'social_icons_google_select',
				'social_icons_google_color',
				'social_icons_vkontakte_url',
				'social_icons_vkontakte_select',
				'social_icons_vkontakte_color',
				'social_icons_linkedin_url',
				'social_icons_linkedin_select',
				'social_icons_linkedin_color',
				'social_icons_youtube_url',
				'social_icons_youtube_select',
				'social_icons_youtube_color',
			),
			'google_map'           => array(
				'google_map_api',
				'google_map_width',
				'google_map_height',
				'google_map_address',
				'google_map_label',
				'google_map_zoom_level',
				'google_map_style',
				'google_map_custom_style',
				'google_map_marker',
			),
			'bing_map'             => array(
				'bing_map_api',
				'bing_map_width',
				'bing_map_height',
				'bing_map_address',
				'bing_map_label',
				'bing_map_zoom_level',
				'bing_map_view',
				'bing_map_navbarmode',
				'bing_map_marker'
			),
		);
		$woo_thank_you_page_settings = get_option( 'woo_thank_you_page_params', [] );
		if ( empty( $woo_thank_you_page_settings ) ) {
			$woo_thank_you_page_settings = $this->settings->get_default();
		}
		if ( ! isset( $woo_thank_you_page_settings['template_0'] ) ) {
			update_option( 'woo_thank_you_page_params_old_version', $woo_thank_you_page_settings );/*backup data*/
			$template_data_default = array();
			/*merge data block old to new data Template default*/
			foreach ( $list_blocks_helper as $block_item ) {
				$components = $list_child_components[ $block_item ];
				foreach ( $components as $component_item ) {
					$convert_data = isset( $woo_thank_you_page_settings[ $component_item ] ) ? $woo_thank_you_page_settings[ $component_item ] : 'not_exist';
					if ( $convert_data != 'not_exist' ) {

						$template_data_default['template_0'][ $component_item ] = $convert_data;
					}
				}
			}
			/*merge data content old to new data Template default*/
			foreach ( $list_contents_helper as $content_item ) {
				$convert_data = isset( $woo_thank_you_page_settings[ $content_item ] ) ? $woo_thank_you_page_settings[ $content_item ] : 'not_exist';
				if ( $convert_data != 'not_exist' ) {
					$template_data_default['template_0'][ $content_item ] = $convert_data;
				}

			}
			$new_woo_thank_you_page_settings = wp_parse_args( $template_data_default, $woo_thank_you_page_settings );


			$args   = array(
				'limit'  => 1,
				'return' => 'ids',
			);
			$orders = wc_get_orders( $args );

			if ( ! empty( $orders ) ) {
				foreach ( $orders as $order ) {
					$new_woo_thank_you_page_settings['select_order'] = $order;
				}
			}

			update_option( 'woo_thank_you_page_params', $new_woo_thank_you_page_settings );

		}
	}

}